@@ -5,23 +5,35 @@ import json
 from fanstatic import Library
 from fanstatic import Resource
 from js.tinymce import tinymce
-from js.tinymce import tinymcepopup
 from kotti.resources import Content
 from kotti.resources import File
 from kotti.resources import Image
 from kotti.util import _
 from kotti.util import title_to_name
-from kotti.views.image import image_scales
 from pyramid.httpexceptions import HTTPFound
 from pyramid.response import Response
 from pyramid.view import view_config
 from pyramid.view import view_defaults
 
 library = Library('kotti_tinymce', 'static')
-kotti_tinymce = Resource(library,
-                         "kotti_tinymce.js",
-                         minified="kotti_tinymce.min.js",
-                         depends=[tinymce, ])
+
+kotti_tinymce = Resource(
+    library,
+    "kotti_tinymce.js",
+    minified="kotti_tinymce.min.js",
+    depends=[tinymce, ]
+)
+codemirror_plugin = Resource(
+    library,
+    "codemirror/plugin.js",
+    depends=[tinymce, ]
+)
+kottiimage_plugin = Resource(
+    library,
+    "kottiimage_plugin.js",
+    minified="kottiimage_plugin.min.js",
+    depends=[tinymce, ]
+)
 
 
 @view_defaults(context=Content,
@@ -33,9 +45,9 @@ class KottiTinyMCE():
         self.context = context
         self.request = request
 
-        # put the requested type (image or file) into the session to
+        # Put the requested type (image or file) into the session to
         # enable browsing through the navigation tree without having
-        # to take special care while generation URLs
+        # to take special care while generating URLs.
         if "type" in request.GET:
             request.session["kottibrowser_requested_type"] = request.GET["type"]
         else:
@@ -77,20 +89,19 @@ class KottiTinyMCE():
                  renderer="kotti_tinymce:templates/kottibrowser.pt")
     def kottibrowser(self):
 
-        tinymcepopup.need()
         kotti_tinymce.need()
 
-        scales = [{
-            "size": size,
-            "value": name,
-            "title": name,
-        } for (name, size) in sorted(image_scales.items(), key=lambda x: x[1])]
-
         return {
-            "image_selectable": self.context.type == self.request.session["kottibrowser_requested_type"] == "image",
-            "link_selectable": self.request.session["kottibrowser_requested_type"] != "image",
-            "image_url": self.request.resource_url(self.context) + 'image',
-            "image_scales": scales,
+            "image_selectable":
+            self.context.type ==
+            self.request.session["kottibrowser_requested_type"] == "image",
+
+            "link_selectable":
+            self.request.session["kottibrowser_requested_type"] != "image",
+
+            "image_url":
+            self.request.resource_url(self.context) + 'image/span1',
+
             # TODO: upload_allowed needs a better check.
             "upload_allowed": self.context.type == 'document',
         }
@@ -137,7 +148,7 @@ class KottiTinyMCE():
             filename=filename,
             mimetype=mimetype,
             size=size
-            )
+        )
 
         self.request.session.flash(_("Successfully uploaded."), "success")
 
@@ -160,6 +171,8 @@ def includeme(config):
         # kotti >= 0.8
         from js.deform import resource_mapping
         edit_needed = resource_mapping['tinymce'].append(kotti_tinymce)
+        resource_mapping['tinymce'].append(kottiimage_plugin)
+        resource_mapping['tinymce'].append(codemirror_plugin)
     except ImportError:  # pragma: no cover
         # kotti < 0.8
         from kotti.static import edit_needed
